@@ -10,7 +10,7 @@ library(lidR)
 
 ## ---- echo = FALSE------------------------------------------------------------
 
-data = data.table::data.table(
+data = data.frame(
   Max.X   = c(885228.88, 886993.96, 885260.93, 887025.96,
               885292.94, 887056.88, 892199.94, 893265.54, 892229.99, 893295.15,
               888759.96, 890524.95, 892259.98, 894025.98, 892289.96, 894055.93,
@@ -80,21 +80,18 @@ data = data.table::data.table(
 )
 
 
-pgeom <- lapply(1:nrow(data), function(i)
+geom <- lapply(1:nrow(data), function(i)
 {
   mtx <- matrix(c(data$Min.X[i], data$Max.X[i], data$Min.Y[i], data$Max.Y[i])[c(1, 1, 2, 2, 1, 3, 4, 4, 3, 3)], ncol = 2)
-  sp::Polygons(list(sp::Polygon(mtx)),as.character(i))
+  sf::st_polygon(list(mtx))
 })
 
-Sr = sp::SpatialPolygons(pgeom, proj4string = sp::CRS("+init=epsg:3005"))
+geom <-sf::st_sfc(geom)
+sf::st_crs(geom) <- 26917
+data <- sf::st_set_geometry(data, geom)
 
-ctg <- new("LAScatalog")
-ctg@bbox <- Sr@bbox
-ctg@proj4string <- Sr@proj4string
-ctg@plotOrder <- Sr@plotOrder
-ctg@data <- data
-ctg@polygons <- Sr@polygons
-ctg@data$Number.of.point.records <- 11234567
+ctg       <- new("LAScatalog")
+ctg@data  <- data
 
 ## -----------------------------------------------------------------------------
 ctg
@@ -109,7 +106,7 @@ las_check(ctg)
 plot(ctg)
 
 ## ---- warning=FALSE-----------------------------------------------------------
-spplot(ctg, "Min.Z")
+plot(ctg["Min.Z"])
 
 ## -----------------------------------------------------------------------------
 summary(ctg)
